@@ -1,5 +1,8 @@
 use perseus_cli::errors::*;
-use perseus_cli::{build, check_env, delete_bad_dir, help, prepare, serve, PERSEUS_VERSION};
+use perseus_cli::{
+    build, check_env, delete_artifacts, delete_bad_dir, eject, has_ejected, help, prepare, serve,
+    PERSEUS_VERSION,
+};
 use std::env;
 use std::io::Write;
 use std::path::PathBuf;
@@ -8,7 +11,9 @@ use std::path::PathBuf;
 fn main() {
     // In development, we'll test in the `basic` example
     if cfg!(debug_assertions) {
-        env::set_current_dir("../../examples/basic").unwrap();
+        let example_to_test =
+            env::var("TEST_EXAMPLE").unwrap_or_else(|_| "../../examples/basic".to_string());
+        env::set_current_dir(example_to_test).unwrap();
     }
     let exit_code = real_main();
     std::process::exit(exit_code)
@@ -57,6 +62,10 @@ fn core(dir: PathBuf) -> Result<i32> {
     let _executable_name = prog_args.remove(0);
     // Check the user's environment to make sure they have prerequisites
     check_env()?;
+    // Warn the user if they're using the CLI single-threaded mode
+    if env::var("PERSEUS_CLI_SEQUENTIAL").is_ok() {
+        writeln!(stdout, "Note: the Perseus CLI is running in single-threaded mode, which is less performant on most modern systems. You can switch to multi-threaded mode by unsetting the 'PERSEUS_CLI_SEQUENTIAL' environment variable. If you've deliberately enabled single-threaded mode, you can safely ignore this.\n").expect("Failed to write to stdout.");
+    }
     // Check for special arguments
     if matches!(prog_args.get(0), Some(_)) {
         if prog_args[0] == "-v" || prog_args[0] == "--version" {
@@ -70,20 +79,44 @@ fn core(dir: PathBuf) -> Result<i32> {
             if prog_args[0] == "build" {
                 // Set up the '.perseus/' directory if needed
                 prepare(dir.clone())?;
+                // Delete old build artifacts
+                delete_artifacts(dir.clone(), "static")?;
                 let exit_code = build(dir, &prog_args)?;
                 Ok(exit_code)
             } else if prog_args[0] == "serve" {
                 // Set up the '.perseus/' directory if needed
                 prepare(dir.clone())?;
+                // Delete old build artifacts if `--no-build` wasn't specified
+                if !prog_args.contains(&"--no-build".to_string()) {
+                    delete_artifacts(dir.clone(), "static")?;
+                }
                 let exit_code = serve(dir, &prog_args)?;
                 Ok(exit_code)
             } else if prog_args[0] == "prep" {
+                // This command is deliberately undocumented, it's only used for testing
                 // Set up the '.perseus/' directory if needed
                 prepare(dir.clone())?;
                 Ok(0)
+            } else if prog_args[0] == "eject" {
+                // Set up the '.perseus/' directory if needed
+                prepare(dir.clone())?;
+                eject(dir)?;
+                Ok(0)
             } else if prog_args[0] == "clean" {
-                // Just delete the '.perseus/' directory directly, as we'd do in a corruption
-                delete_bad_dir(dir)?;
+                if prog_args[1] == "--dist" {
+                    // The user only wants to remove distribution artifacts
+                    // We don't delete `render_conf.json` because it's literally impossible for that to be the source of a problem right now
+                    delete_artifacts(dir.clone(), "static")?;
+                    delete_artifacts(dir.clone(), "pkg")?;
+                } else {
+                    // This command deletes the `.perseus/` directory completely, which musn't happen if the user has ejected
+                    if has_ejected(dir.clone()) && prog_args[1] != "--force" {
+                        bail!(ErrorKind::CleanAfterEjection)
+                    }
+                    // Just delete the '.perseus/' directory directly, as we'd do in a corruption
+                    delete_bad_dir(dir)?;
+                }
+
                 Ok(0)
             } else {
                 writeln!(
